[Python-checkins] python/dist/src setup.py,1.171.6.2,1.171.6.3

kbk at users.sourceforge.net kbk at users.sourceforge.net
Mon Jan 17 22:08:37 CET 2005


Update of /cvsroot/python/python/dist/src
In directory sc8-pr-cvs1.sourceforge.net:/tmp/cvs-serv13270

Modified Files:
      Tag: release23-maint
	setup.py 
Log Message:
Backport Patch #850977: Detect Tk on FreeBSD and OpenBSD.


Index: setup.py
===================================================================
RCS file: /cvsroot/python/python/dist/src/setup.py,v
retrieving revision 1.171.6.2
retrieving revision 1.171.6.3
diff -u -d -r1.171.6.2 -r1.171.6.3
--- setup.py	21 Oct 2003 20:01:21 -0000	1.171.6.2
+++ setup.py	17 Jan 2005 21:07:49 -0000	1.171.6.3
@@ -960,17 +960,25 @@
 
         # Now check for the header files
         if tklib and tcllib:
             # Check for the include files on Debian, where
             # they're put in /usr/include/{tcl,tk}X.Y
-            debian_tcl_include = [ '/usr/include/tcl' + version ]
-            debian_tk_include =  [ '/usr/include/tk'  + version ] + \
-                                 debian_tcl_include
-            tcl_includes = find_file('tcl.h', inc_dirs, debian_tcl_include)
-            tk_includes = find_file('tk.h', inc_dirs, debian_tk_include)
+            dotversion = version
+            if '.' not in dotversion and "bsd" in sys.platform.lower():
+                # OpenBSD and FreeBSD use Tcl/Tk library names like libtcl83.a,
+                # but the include subdirs are named like .../include/tcl8.3.
+                dotversion = dotversion[:-1] + '.' + dotversion[-1]
+            tcl_include_sub = []
+            tk_include_sub = []
+            for dir in inc_dirs:
+                tcl_include_sub += [dir + os.sep + "tcl" + dotversion]
+                tk_include_sub += [dir + os.sep + "tk" + dotversion]
+            tk_include_sub += tcl_include_sub
+            tcl_includes = find_file('tcl.h', inc_dirs, tcl_include_sub)
+            tk_includes = find_file('tk.h', inc_dirs, tk_include_sub)
 
         if (tcllib is None or tklib is None or
             tcl_includes is None or tk_includes is None):
-            # Something's missing, so give up
+            self.announce("INFO: Can't locate Tcl/Tk libs and/or headers", 2)
             return
 
         # OK... everything seems to be present for Tcl/Tk.
@@ -960,17 +960,25 @@
         # Now check for the header files
         if tklib and tcllib:
-            # Check for the include files on Debian, where
+            # Check for the include files on Debian and {Free,Open}BSD, where
             # they're put in /usr/include/{tcl,tk}X.Y



More information about the Python-checkins mailing list